@@ -2,6 +2,8 @@ package DB::Introspector;
 
 use strict;
 
+$DB::Introspector::VERSION = '0.06';
+
 use DBI;
 use Config::Properties;
 use IO::File;
@@ -13,6 +15,7 @@ use vars qw( %REGISTRY %INC );
 DB::Introspector->register_drivers();
 
 
+
 sub lookup_table {
     my $self = shift;
     die("lookup_table method not defined in ". (ref($self) || $self)); 
@@ -143,6 +146,23 @@ sub dbh {
     return $self->{_dbh};
 }
 
+sub _clear_dbh {
+    my $self = shift;
+    delete $self->{_dbh};
+}
+
+sub _set_dbh {
+    my $self = shift;
+    if( @_ ) {
+        my $dbh = shift;
+        unless( UNIVERSAL::isa($dbh, 'DBI::db') ) {
+            die("$dbh is not a DBI::db");
+        }
+        $self->{_dbh} = $dbh;
+    }
+
+}
+
 sub _cached_table {
     my $self = shift;
     my $table_name = shift;
@@ -198,7 +218,7 @@ DB::Introspector
           ." is pointing to me\n";
  }
  
- my @tables = $introspector->find_tables;
+ my @tables = $introspector->find_all_tables;
 
  # you can do other cool stuff; just read the docs.
 
